#include "TelepathyQt/_gen/svc-debug.h"

#include "TelepathyQt/_gen/svc-debug.moc.hpp"

#include <TelepathyQt/Constants>
#include <TelepathyQt/MethodInvocationContext>

namespace Tp
{
namespace Service
{

DebugAdaptor::DebugAdaptor(const QDBusConnection& bus, QObject* adaptee, QObject* parent)
    : Tp::AbstractAdaptor(bus, adaptee, parent)
{
    connect(adaptee, SIGNAL(newDebugMessage(double, const QString&, uint, const QString&)), SIGNAL(NewDebugMessage(double, const QString&, uint, const QString&)));
}

DebugAdaptor::~DebugAdaptor()
{
}

bool DebugAdaptor::Enabled() const
{
    return qvariant_cast< bool >(adaptee()->property("enabled"));
}

void DebugAdaptor::SetEnabled(const bool &newValue)
{
    adaptee()->setProperty("enabled", qVariantFromValue(newValue));
}

Tp::DebugMessageList DebugAdaptor::GetMessages(const QDBusMessage& dbusMessage)
{
    if (adaptee()->metaObject()->indexOfMethod("getMessages(Tp::Service::DebugAdaptor::GetMessagesContextPtr)") < 0) {
        dbusConnection().send(dbusMessage.createErrorReply(TP_QT_ERROR_NOT_IMPLEMENTED, QLatin1String("Not implemented")));
        return Tp::DebugMessageList();
    }

    GetMessagesContextPtr ctx = GetMessagesContextPtr(
            new Tp::MethodInvocationContext< Tp::DebugMessageList >(dbusConnection(), dbusMessage));
    QMetaObject::invokeMethod(adaptee(), "getMessages",
        Q_ARG(Tp::Service::DebugAdaptor::GetMessagesContextPtr, ctx));
    return Tp::DebugMessageList();
}

}
}